==> udav_0.5.2.orig.tar.gz: udav-0.5.2/src/helpwindow.h <==
/***************************************************************************
 *   Copyright (C) 2008 by Alexey Balakin                                  *
 *   mathgl.abalakin@gmail.com                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef HELPWINDOW_H
#define HELPWINDOW_H
//-----------------------------------------------------------------------------
#include <qmainwindow.h>
//-----------------------------------------------------------------------------
class QTextBrowser;
extern QString pathHelp;
//-----------------------------------------------------------------------------
/// Window for showing MGL help and examples
class HelpWindow : public QMainWindow
{
Q_OBJECT
public:
	HelpWindow(QWidget *parent = 0);
	~HelpWindow();
public slots:
	void showExamples();
	void showHelp(const QString &cmd=QString::null);
private:
	QTextBrowser *hlp;
};
//-----------------------------------------------------------------------------
#endif
//-----------------------------------------------------------------------------

==> udav_0.6.3.orig.tar.gz: udav-0.6.3/src/helpwindow.h <==
/***************************************************************************
 *   Copyright (C) 2008 by Alexey Balakin                                  *
 *   mathgl.abalakin@gmail.com                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef HELPWINDOW_H
#define HELPWINDOW_H
//-----------------------------------------------------------------------------
#include <QMdiSubWindow>
//-----------------------------------------------------------------------------
class QTextBrowser;
class QLineEdit;
extern QString pathHelp;
class QCloseEvent;
//-----------------------------------------------------------------------------
/// Window for showing MGL help and examples
class HelpWindow : public QMdiSubWindow
{
Q_OBJECT
public:
	HelpWindow(QWidget *parent = 0);
	~HelpWindow();
public slots:
	void closeEvent(QCloseEvent *);
	void showExamples();
	void showHelp(const QString &cmd=QString::null);
	void setPath(const QString &path);
	void zoomIn();
	void zoomOut();
private:
	QTextBrowser *help;
	QLineEdit *entry;
};
//-----------------------------------------------------------------------------
#endif
//-----------------------------------------------------------------------------
